.. include:: /_includes/wip_prolog.rst

:mod:`stix.utils.nsparser` Module
==================================

.. module:: stix.utils.nsparser

Classes
-------

.. autoclass:: NamespaceParser
	:show-inheritance:
	:members:

Constants
---------

.. autodata:: XML_NAMESPACES

.. autodata:: STIX_NS_TO_SCHEMALOCATION

.. autodata:: EXT_NS_TO_SCHEMALOCATION

.. autodata:: DEFAULT_STIX_NS_TO_PREFIX

.. autodata:: DEFAULT_EXT_TO_PREFIX
